@@ -26,6 +26,7 @@ from lizard_map.workspace import WorkspaceManager
 
 def workspace(request,
               workspace_id,
+              javascript_click_handler=None,
               template='lizard_map/workspace.html'):
     """Render page with one workspace"""
     workspace = get_object_or_404(Workspace, pk=workspace_id)
@@ -34,6 +35,7 @@ def workspace(request,
     return render_to_response(
         template,
         {'workspaces': {'user': [workspace]},
+         'javascript_click_handler': javascript_click_handler,
          'date_range_form': date_range_form},
         context_instance=RequestContext(request))
 
@@ -203,7 +205,7 @@ def popup_json(found, popup_id=None, collage=False, request=None):
             name = display_object.get('name', 'Geen naam')
             shortname = display_object.get('shortname', '')
             workspace_item = display_object['workspace_item']
-            identifier_json = simplejson.dumps(display_object['identifier'])
+            identifier_json = simplejson.dumps(display_object['identifier']).replace('"', '%22')
             identifier_json_list.append(identifier_json)
 
             # Add workspace_item on top
@@ -236,7 +238,7 @@ def popup_json(found, popup_id=None, collage=False, request=None):
                               })
         img = img + '?' + '&'.join(['identifier=%s' % i for i in
                                     identifier_json_list])
-        body = "<div><img src='%s' /></div>" % img
+        body = '<div><img src="%s" /></div>' % img
         html_per_workspace_item = header + body
         x_found, y_found = display_object['google_coords']
         result_html += html_per_workspace_item
@@ -353,9 +355,12 @@ def workspace_item_image(request, workspace_item_id):
     identifier_json_list = request.GET.getlist('identifier')
     identifier_list = [simplejson.loads(json) for json in identifier_json_list]
 
+    width = request.GET.get('width', None)
+    height = request.GET.get('height', None)
+
     workspace_item = get_object_or_404(WorkspaceItem, pk=workspace_item_id)
     start_date, end_date = current_start_end_dates(request)
-    return workspace_item.adapter.image(identifier_list, start_date, end_date)
+    return workspace_item.adapter.image(identifier_list, start_date, end_date, width, height)
 
 """
 Map stuff
